import base
import ConfigParser

CONFIG_FILE = "/etc/sandglass.conf"

def get_instance():
	return Config.get_instance()

class Config(base.Flyweight):
	def __init__(self, filename=None):
		super(Config, self).__init__()
		if filename is None:
			filename = CONFIG_FILE

		self._parser = ConfigParser.SafeConfigParser()
		self._parser.read(filename)

	def _parse_key(self, key):
		return key.split(".", 1)

	def _delegate_get(self, function_name, key, default):
		(section, option) = self._parse_key(key)
		function = getattr(self._parser, function_name)
		try:
			return function(section, option)
		except (ConfigParser.NoSectionError, ConfigParser.NoOptionError):
			return default

	def get(self, key, default=None):
		return self._delegate_get("get", key, default)

	def getint(self, key, default=0):
		return self._delegate_get("getint", key, default)

	def getfloat(self, key, default=0.0):
		return self._delegate_get("getfloat", key, default)

	def getboolean(self, key, default=False):
		return self._delegate_get("getboolean", key, default)

	def __getitem__(self, key):
		return self.get(key)
