import os

BLACKLISTED_FILES = [ "/etc/shadow", "/etc/gshadow" ]

class DistInfoBase(object):
	def __init__(self):
		pass

	def _config_files(self):
		raise NotImplementedError()

	def _filter_files(self, files, prefix=None, must_exist=True, ignore_blacklist=False):
		filtered = []
		for name in files:
			if prefix is not None and not name.startswith(prefix):
				pass
			elif must_exist and not os.path.exists(name):
				pass
			elif not ignore_blacklist and name in BLACKLISTED_FILES:
				pass
			else:
				filtered.append(name)
		return filtered

	def config_files(self, prefix=None, must_exist=True, ignore_blacklist=False):
		files = self._config_files()
		return self._filter_files(files, prefix, must_exist, ignore_blacklist)

	def package_files(self, package, prefix=None, must_exist=True, ignore_blacklist=False):
		package_files = []
		all_files = self._config_files()
		for path in all_files:
			if all_files[path] == package:
				package_files.append(path)
		return self._filter_files(package_files, prefix, must_exist, ignore_blacklist)

	def is_config(self, path):
		files = self._config_files()
		return path in files

	def file_package(self, path):
		files = self._config_files()
		if path in files:
			return files[path]
		else:
			return None

	def invalidate_cache(self):
		pass
