import base
import sandglass

RPM_BINARY = "/bin/rpm"
RPM_DATABASE_MTIME_FILE = "/var/lib/rpm/Basenames"
CACHE_FILE = "packages"

class DistInfo(base.DistInfoBase):

	def _load_cache(self):
		try:
			self._cache_pkgs
		except AttributeError:
			self._cache_pkgs = sandglass.cache.Cache(CACHE_FILE)

	def _create_cache(self):
		# This has to be done in two steps
		# 1. getting the list of all configuration files
		# 2. assigning package names to the files

		rpm_files = sandglass.utils.Command([RPM_BINARY, "-qac", "--nodigest", "--nosignature"])
		if rpm_files.exit_code != 0:
			raise Exception()

		files = {}
		for file in rpm_files.stdout.splitlines():
			# filter out results which are not files
			if file.startswith("("):
				continue

			if files.has_key(file):
				continue

			rpm_owner = sandglass.utils.Command([RPM_BINARY, "-qcf", "--qf=%{name}\n",
									"--nodigest", "--nosignature", file])
			if rpm_owner.exit_code != 0:
				# TODO
				raise Exception(rpm_owner.stderr)

			lines = rpm_owner.stdout.split("\n")
			package = lines.pop(0)
			for file in lines:
				files.setdefault(file, package)

		self._cache_pkgs.data = files

	def _config_files(self):
		self._load_cache()
		if self._cache_pkgs.data is None or self._cache_pkgs.saved_at() < sandglass.utils.file_mtime(RPM_DATABASE_MTIME_FILE):
			self._create_cache()
			assert self._cache_pkgs.data is not None

		return self._cache_pkgs.data

	def invalidate_cache(self):
		self._cache_pkgs.data = None
