import os
import git

class Repo(git.Repo):
	def __init__(self, repo_dir, work_dir):
		self._sgl_clean_git_environment()
		git.Repo.__init__(self, repo_dir)
		os.environ["GIT_DIR"] = repo_dir

		# WORKAROUND: GitPython doesn't support GIT_WORK_TREE/core.worktree (but we do)
		if work_dir is not None:
			self._working_tree_dir = work_dir
			self._bare = False

		self.git = GitCmd(working_dir = work_dir)

	def _sgl_clean_git_environment(self):
		"""Unset all environment variables with GIT_ prefix."""
		remove = [key for key in os.environ if key.startswith("GIT_")]
		for key in remove:
			del os.environ[key]

class GitCmd(git.cmd.Git):
	def execute(self, *args, **kwargs):
		kwargs.setdefault("with_keep_cwd", True)
		kwargs.setdefault("with_exceptions", True)

		return git.cmd.Git.execute(self, *args, **kwargs)
